############################
Python Schematron
############################

Schematron validation in Python.


*******
Summary
*******
* Free software: GPL v3 license
* Full documentation: https://pyschematron.readthedocs.io
* Project home: https://github.com/robbert-harms/pyschematron


************************
Quick installation guide
************************


**Linux**


**Windows**


**Mac**
